#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.interface import Interface, implementer
from zope.location import Location
from zope.schema.fieldproperty import FieldProperty

from onf_website import _
from onf_website.features.menu.skin.interfaces import IONFExternalNavigationPortletRendererSettings, \
    IONFNavigationPortletRendererSettings
from onf_website.skin.public import aside_sticky, owl_carousel_init, owl_navigation
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.menu.portlet.navigation.interfaces.simple import ISimpleNavigationPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config


#
# Generic navigation portlet settings
#

@implementer(IONFNavigationPortletRendererSettings)
@factory_config(provided=IONFNavigationPortletRendererSettings)
class ONFNavigationTabsPortletRendererSettings(Persistent, Location):
    """ONF navigation portlet renderer settings"""

    subtitle = FieldProperty(IONFNavigationPortletRendererSettings['subtitle'])
    header = FieldProperty(IONFNavigationPortletRendererSettings['header'])


#
# Base simple navigation portlet renderer
#

class ONFBaseSimpleNavigationPortletRenderer(PortletRenderer):
    """ONF base simple navigation portlet renderer"""

    settings_interface = IONFNavigationPortletRendererSettings

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)


#
# Horizontal tabs navigation portlet renderer
#

@adapter_config(name='ONF::navigation-tabs',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-tabs.pt', layer=IPyAMSLayer)
class ONFNavigationTabsPortletRenderer(ONFBaseSimpleNavigationPortletRenderer):
    """ONF horizontal tabs navigation portlet renderer"""

    label = _("ONF: Horizontal navigation tabs")
    weight = 10


# Vertical illustrations portlet renderer
#

@adapter_config(name='ONF::navigation-illustration-vertical',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-illustration-vertical.pt', layer=IPyAMSLayer)
class ONFNavigationIllustrationVerticalPortletRenderer(ONFBaseSimpleNavigationPortletRenderer):
    """ONF vertical illustrations navigation portlet renderer"""

    label = _("ONF: Vertical illustrations navigation")
    weight = 11

    resources = (owl_carousel_init, owl_navigation)


#
# Horizontal navigation with background illustrations portlet renderer
#

@adapter_config(name='ONF::navigation-illustration-shortcuts',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-shortcuts.pt', layer=IPyAMSLayer)
class ShortcutNavigationPortletRenderer(ONFBaseSimpleNavigationPortletRenderer):
    """ONF Simple navigation horizontal portlet renderer with tabs"""

    label = _("ONF: Horizontal links list with background illustrations")
    weight = 12


#
# External navigation portlet settings
#

@implementer(IONFExternalNavigationPortletRendererSettings)
@factory_config(provided=IONFExternalNavigationPortletRendererSettings)
class ONFExternalNavigationPortletRendererSettings(Persistent, Location):
    """ONF external navigation portlet renderer settings"""

    button_label = FieldProperty(IONFExternalNavigationPortletRendererSettings['button_label'])


#
# External navigation with background illustrations portlet renderer
#

@adapter_config(name='ONF::navigation-external-shortcuts',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-external-shortcuts.pt', layer=IPyAMSLayer)
class ONFExternalShortcutNavigationPortletRenderer(ONFBaseSimpleNavigationPortletRenderer):
    """ONF External navigation portlet renderer"""

    label = _("ONF: External navigation links with illustrations")
    weight = 13

    settings_interface = IONFExternalNavigationPortletRendererSettings


#
#  Useful links vertical navigation portlet renderer
#

@adapter_config(name='ONF::navigation-vertical-useful-links',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-vertical-useful-links.pt', layer=IPyAMSLayer)
class ONFNavigationVerticalUsefulLinksPortletRenderer(ONFBaseSimpleNavigationPortletRenderer):
    """ONF Useful links vertical navigation portlet renderer"""

    label = _("ONF: Useful links vertical list")
    weight = 14

    settings_interface = None

    resources = (aside_sticky,)
